@@ -36,7 +36,7 @@ func (l *Logger) Init(_ context.Context) error {
 	if l.title != "" {
 		l.SetBorder(true)
 	}
-	l.SetScrollable(true).SetWrap(true).SetRegions(true)
+	l.SetScrollable(true).SetWrap(true)
 	l.SetDynamicColors(true)
 	l.SetHighlightColor(tcell.ColorOrange)
 	l.SetTitleColor(tcell.ColorAqua)
